@@ -42,10 +42,10 @@
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <gmyth_backendinfo.h>
-#include <gmyth_file_transfer.h>
-#include <gmyth_scheduler.h>
-#include <gmyth_util.h>
+#include <gmyth/gmyth_backendinfo.h>
+#include <gmyth/gmyth_file_transfer.h>
+#include <gmyth/gmyth_scheduler.h>
+#include <gmyth/gmyth_util.h>
 
 #define TOTEM_TYPE_MYTHTV_PLUGIN		(totem_mythtv_plugin_get_type ())
 #define TOTEM_MYTHTV_PLUGIN(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), TOTEM_TYPE_MYTHTV_PLUGIN, TotemMythtvPlugin))
@@ -376,7 +376,8 @@ impl_activate (TotemPlugin *plugin,
 					GTK_POLICY_NEVER,
 					GTK_POLICY_AUTOMATIC);
 	create_treeview (tm);
-	gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (tm->treeview));
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolled),
+					       GTK_WIDGET (tm->treeview));
 	gtk_container_add (GTK_CONTAINER (box), scrolled);
 	gtk_box_pack_end (GTK_BOX (box), button, FALSE, FALSE, 0);
 	gtk_widget_show_all (box);
@@ -389,11 +390,12 @@ impl_activate (TotemPlugin *plugin,
 
 	totem_mythtv_update_binfo (TOTEM_MYTHTV_PLUGIN(plugin));
 
-	totem_gdk_window_set_waiting_cursor (box->window);
 	/* FIXME we should only do that if it will be done in the background */
-	/* totem_mythtv_list_recordings (TOTEM_MYTHTV_PLUGIN(plugin)); */
+#if 0
+	totem_gdk_window_set_waiting_cursor (box->window);
+	totem_mythtv_list_recordings (TOTEM_MYTHTV_PLUGIN(plugin));
 	gdk_window_set_cursor (box->window, NULL);
-
+#endif
 	return TRUE;
 }
 
