@@ -214,7 +214,7 @@ totem_get_plugin_paths (void)
 	paths = NULL;
 
 	client = gconf_client_get_default ();
-	if (gconf_client_get_bool (client, GCONF_PREFIX"/disable_user_plugins", NULL) != FALSE) {
+	if (gconf_client_get_bool (client, GCONF_PREFIX"/disable_user_plugins", NULL) == FALSE) {
 		path = g_build_filename (totem_dot_dir (), "plugins", NULL);
 		paths = g_list_prepend (paths, path);
 	}
